# Fast and Lightweight Vision-based RL Framework

## Installation

OmegaConf v2.0 is not compatible with stable Hydra. Please install hydra from master branch.

```bash
pip install git+https://github.com/facebookresearch/hydra.git@master

# install hydra colorlog plugin
pip install 'git+https://github.com/facebookresearch/hydra.git#egg=hydra&subdirectory=plugins/hydra_colorlog'
```
